diff --git a/cumulus/docker/docker-compose.yml b/cumulus/docker/docker-compose.yml
index 6372b71cf62ff7504ed08271e931e75e658a176d..052879039aeb1381496bb0377fdb8f68eb41a5b1 100644
--- a/cumulus/docker/docker-compose.yml
+++ b/cumulus/docker/docker-compose.yml
@@ -66,7 +66,7 @@ services:
     volumes:
       - "genesis-state:/data"
     command: >
-      rococo-collator
+      polkadot-collator
       export-genesis-state
       /data/genesis-state
 
diff --git a/cumulus/docker/test-parachain-collator.dockerfile b/cumulus/docker/test-parachain-collator.dockerfile
index 73454501c5a7ffb9bb57819d52bf27680d1a4bf1..37f1ffe4777055469708d824235696573bcc9135 100644
--- a/cumulus/docker/test-parachain-collator.dockerfile
+++ b/cumulus/docker/test-parachain-collator.dockerfile
@@ -19,7 +19,7 @@ WORKDIR /paritytech/cumulus
 # not the actual directory. We're stuck just enumerating them.
 COPY . .
 
-RUN cargo build --release -p rococo-collator
+RUN cargo build --release -p polkadot-collator
 
 # the collator stage is normally built once, cached, and then ignored, but can
 # be specified with the --target build flag. This adds some extra tooling to the
@@ -38,7 +38,7 @@ RUN apt-get update && apt-get install jq curl bash -y && \
     npm install --global yarn && \
     yarn global add @polkadot/api-cli@0.10.0-beta.14
 COPY --from=builder \
-    /paritytech/cumulus/target/release/rococo-collator /usr/bin
+    /paritytech/cumulus/target/release/polkadot-collator /usr/bin
 COPY ./docker/scripts/inject_bootnodes.sh /usr/bin
 CMD ["/usr/bin/inject_bootnodes.sh"]
 COPY ./docker/scripts/healthcheck.sh /usr/bin/
@@ -56,6 +56,6 @@ CMD ["cp", "-v", "/var/opt/cumulus_test_parachain_runtime.compact.wasm", "/runti
 
 FROM debian:buster-slim
 COPY --from=builder \
-    /paritytech/cumulus/target/release/rococo-collator /usr/bin
+    /paritytech/cumulus/target/release/polkadot-collator /usr/bin
 
-CMD ["/usr/bin/rococo-collator"]
+CMD ["/usr/bin/polkadot-collator"]
diff --git a/cumulus/docker/scripts/inject_bootnodes.sh b/cumulus/docker/scripts/inject_bootnodes.sh
index df8cdacb177747182a77afe3e9a3f3e3ef18e105..99740a3fab1bd3c6a2f0b9327500e15cfdbacef9 100755
--- a/cumulus/docker/scripts/inject_bootnodes.sh
+++ b/cumulus/docker/scripts/inject_bootnodes.sh
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
 # this script runs the rococo-collator after fetching
 # appropriate bootnode IDs
 #
 # this is _not_ a general-purpose script; it is closely tied to the
@@ -8,7 +8,7 @@
 
 set -e -o pipefail
 
-ctpc="/usr/bin/rococo-collator"
+ctpc="/usr/bin/polkadot-collator"
 
 if [ ! -x "$ctpc" ]; then
     echo "FATAL: $ctpc does not exist or is not executable"
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# this script runs the rococo-collator after fetching
+# this script runs the polkadot-collator after fetching
 # appropriate bootnode IDs
 #